==> haskell-doctest-0.17-69-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-doctest.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 doctest
version:              0.17
visibility:           public
id:                   doctest-0.17-y5V5Nibj7W1YEgRKeWWx
key:                  doctest-0.17-y5V5Nibj7W1YEgRKeWWx
license:              MIT
copyright:            (c) 2009-2018 Simon Hengel
maintainer:           quasicomputational <quasicomputational@gmail.com>
author:               Simon Hengel <sol@typeful.net>
homepage:             https://github.com/sol/doctest#readme
synopsis:             Test interactive Haskell examples
description:
    The doctest program checks examples in source code comments.  It is modeled
    after doctest for Python (<http://docs.python.org/library/doctest.html>).

    Documentation is at <https://github.com/sol/doctest#readme>.

category:             Testing
abi:                  b3d8754f4da9ca390024f0fab921edb4
exposed:              True
exposed-modules:      Test.DocTest
hidden-modules:
    Extract GhcUtil Interpreter Location Options PackageDBs Parse
    Property Run Runner Runner.Example Sandbox Util
    Language.Haskell.GhciWrapper Paths_doctest

import-dirs:          /usr/lib/ghc-8.10.3/site-local/doctest-0.17
library-dirs:         /usr/lib/ghc-8.10.3/site-local/doctest-0.17
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/doctest-0.17
hs-libraries:         HSdoctest-0.17-y5V5Nibj7W1YEgRKeWWx
depends:
    base-4.14.1.0 base-compat-0.11.2-JggHr2fdYLe83DSFk1MYK3
    code-page-0.2-1lNAShZKBs0E8I4pr7cPwp deepseq-1.4.4.0
    directory-1.3.6.0 filepath-1.4.2.1 ghc-8.10.3
    ghc-paths-0.1.0.12-LgiNEBvorJD4Iq1vCUjVLQ process-1.6.9.0
    syb-0.7.2.1-IMisWBQ73CcBLtEce0DtDe transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-doctest/html/doctest.haddock
haddock-html:         /usr/share/doc/haskell-doctest/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-doctest-0.17-75-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-doctest.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 doctest
version:              0.17
visibility:           public
id:                   doctest-0.17-37x50PeuGPoEPVA4RCH25N
key:                  doctest-0.17-37x50PeuGPoEPVA4RCH25N
license:              MIT
copyright:            (c) 2009-2018 Simon Hengel
maintainer:           quasicomputational <quasicomputational@gmail.com>
author:               Simon Hengel <sol@typeful.net>
homepage:             https://github.com/sol/doctest#readme
synopsis:             Test interactive Haskell examples
description:
    The doctest program checks examples in source code comments.  It is modeled
    after doctest for Python (<http://docs.python.org/library/doctest.html>).

    Documentation is at <https://github.com/sol/doctest#readme>.

category:             Testing
abi:                  4bd6d7fa4ceac24f8f17befb61bf79e0
exposed:              True
exposed-modules:      Test.DocTest
hidden-modules:
    Extract GhcUtil Interpreter Location Options PackageDBs Parse
    Property Run Runner Runner.Example Sandbox Util
    Language.Haskell.GhciWrapper Paths_doctest

import-dirs:          /usr/lib/ghc-8.10.3/site-local/doctest-0.17
library-dirs:         /usr/lib/ghc-8.10.3/site-local/doctest-0.17
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/doctest-0.17
hs-libraries:         HSdoctest-0.17-37x50PeuGPoEPVA4RCH25N
depends:
    base-4.14.1.0 base-compat-0.11.2-JggHr2fdYLe83DSFk1MYK3
    code-page-0.2-1lNAShZKBs0E8I4pr7cPwp deepseq-1.4.4.0
    directory-1.3.6.0 filepath-1.4.2.1 ghc-8.10.3
    ghc-paths-0.1.0.12-LgiNEBvorJD4Iq1vCUjVLQ process-1.6.9.0
    syb-0.7.2.1-CJLve2ufQ9iBKjc57rB5t8 transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-doctest/html/doctest.haddock
haddock-html:         /usr/share/doc/haskell-doctest/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
